==> build-failure-analyzer-1.8.0-sources.jar: com/sonyericsson/jenkins/plugins/bfa/Messages.java <==
// CHECKSTYLE:OFF

package com.sonyericsson.jenkins.plugins.bfa;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Failed to scan file
     * 
     */
    public static String FailedToScanFile_Error() {
        return holder.format("FailedToScanFile_Error");
    }

    /**
     * Failed to scan file
     * 
     */
    public static Localizable _FailedToScanFile_Error() {
        return new Localizable(holder, "FailedToScanFile_Error");
    }

    /**
     * String matches pattern
     * 
     */
    public static String StringMatchesPattern() {
        return holder.format("StringMatchesPattern");
    }

    /**
     * String matches pattern
     * 
     */
    public static Localizable _StringMatchesPattern() {
        return new Localizable(holder, "StringMatchesPattern");
    }

    /**
     * Multi-Line Build Log Indication
     * 
     */
    public static String MultilineBuildLogIndication_DisplayName() {
        return holder.format("MultilineBuildLogIndication_DisplayName");
    }

    /**
     * Multi-Line Build Log Indication
     * 
     */
    public static Localizable _MultilineBuildLogIndication_DisplayName() {
        return new Localizable(holder, "MultilineBuildLogIndication_DisplayName");
    }

    /**
     * Add and Update Failure causes.
     * 
     */
    public static String PermissionUpdate_Description() {
        return holder.format("PermissionUpdate_Description");
    }

    /**
     * Add and Update Failure causes.
     * 
     */
    public static Localizable _PermissionUpdate_Description() {
        return new Localizable(holder, "PermissionUpdate_Description");
    }

    /**
     * Could not connect
     * 
     */
    public static String MongoDBKnowledgeBase_ConnectionError() {
        return holder.format("MongoDBKnowledgeBase_ConnectionError");
    }

    /**
     * Could not connect
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_ConnectionError() {
        return new Localizable(holder, "MongoDBKnowledgeBase_ConnectionError");
    }

    /**
     * Remove Failure causes.
     * 
     */
    public static String PermissionRemove_Description() {
        return holder.format("PermissionRemove_Description");
    }

    /**
     * Remove Failure causes.
     * 
     */
    public static Localizable _PermissionRemove_Description() {
        return new Localizable(holder, "PermissionRemove_Description");
    }

    /**
     * Build Failure Analyzer
     * 
     */
    public static String PermissionGroup_Title() {
        return holder.format("PermissionGroup_Title");
    }

    /**
     * Build Failure Analyzer
     * 
     */
    public static Localizable _PermissionGroup_Title() {
        return new Localizable(holder, "PermissionGroup_Title");
    }

    /**
     * Failure Scan Options
     * 
     */
    public static String FailureScan_DisplayName() {
        return holder.format("FailureScan_DisplayName");
    }

    /**
     * Failure Scan Options
     * 
     */
    public static Localizable _FailureScan_DisplayName() {
        return new Localizable(holder, "FailureScan_DisplayName");
    }

    /**
     * Invalid URL
     * 
     */
    public static String InvalidURL_Error() {
        return holder.format("InvalidURL_Error");
    }

    /**
     * Invalid URL
     * 
     */
    public static Localizable _InvalidURL_Error() {
        return new Localizable(holder, "InvalidURL_Error");
    }

    /**
     * Do not Scan failed builds
     * 
     */
    public static String ScannerJobProperty_DisplayName() {
        return holder.format("ScannerJobProperty_DisplayName");
    }

    /**
     * Do not Scan failed builds
     * 
     */
    public static Localizable _ScannerJobProperty_DisplayName() {
        return new Localizable(holder, "ScannerJobProperty_DisplayName");
    }

    /**
     * Mongo DB
     * 
     */
    public static String MongoDBKnowledgeBase_DisplayName() {
        return holder.format("MongoDBKnowledgeBase_DisplayName");
    }

    /**
     * Mongo DB
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_DisplayName() {
        return new Localizable(holder, "MongoDBKnowledgeBase_DisplayName");
    }

    /**
     * Connection OK!
     * 
     */
    public static String MongoDBKnowledgeBase_ConnectionOK() {
        return holder.format("MongoDBKnowledgeBase_ConnectionOK");
    }

    /**
     * Connection OK!
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_ConnectionOK() {
        return new Localizable(holder, "MongoDBKnowledgeBase_ConnectionOK");
    }

    /**
     * String does not match pattern
     * 
     */
    public static String StringDoesNotMatchPattern() {
        return holder.format("StringDoesNotMatchPattern");
    }

    /**
     * String does not match pattern
     * 
     */
    public static Localizable _StringDoesNotMatchPattern() {
        return new Localizable(holder, "StringDoesNotMatchPattern");
    }

    /**
     * Build Log Indication
     * 
     */
    public static String BuildLogIndication_DisplayName() {
        return holder.format("BuildLogIndication_DisplayName");
    }

    /**
     * Build Log Indication
     * 
     */
    public static Localizable _BuildLogIndication_DisplayName() {
        return new Localizable(holder, "BuildLogIndication_DisplayName");
    }

    /**
     * Jenkins Local
     * 
     */
    public static String LocalFileKnowledgeBase_DisplayName() {
        return holder.format("LocalFileKnowledgeBase_DisplayName");
    }

    /**
     * Jenkins Local
     * 
     */
    public static Localizable _LocalFileKnowledgeBase_DisplayName() {
        return new Localizable(holder, "LocalFileKnowledgeBase_DisplayName");
    }

    /**
     * Failure Cause Management
     * 
     */
    public static String CauseManagement_DisplayName() {
        return holder.format("CauseManagement_DisplayName");
    }

    /**
     * Failure Cause Management
     * 
     */
    public static Localizable _CauseManagement_DisplayName() {
        return new Localizable(holder, "CauseManagement_DisplayName");
    }

    /**
     * Invalid pattern
     * 
     */
    public static String InvalidPattern_Error() {
        return holder.format("InvalidPattern_Error");
    }

    /**
     * Invalid pattern
     * 
     */
    public static Localizable _InvalidPattern_Error() {
        return new Localizable(holder, "InvalidPattern_Error");
    }

}

==> build-failure-analyzer-1.13.2-sources.jar: com/sonyericsson/jenkins/plugins/bfa/Messages.java <==
// CHECKSTYLE:OFF

package com.sonyericsson.jenkins.plugins.bfa;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Build Log Indication
     * 
     */
    public static String BuildLogIndication_DisplayName() {
        return holder.format("BuildLogIndication_DisplayName");
    }

    /**
     * Build Log Indication
     * 
     */
    public static Localizable _BuildLogIndication_DisplayName() {
        return new Localizable(holder, "BuildLogIndication_DisplayName");
    }

    /**
     * Add and Update Failure causes.
     * 
     */
    public static String PermissionUpdate_Description() {
        return holder.format("PermissionUpdate_Description");
    }

    /**
     * Add and Update Failure causes.
     * 
     */
    public static Localizable _PermissionUpdate_Description() {
        return new Localizable(holder, "PermissionUpdate_Description");
    }

    /**
     * Remove Failure causes.
     * 
     */
    public static String PermissionRemove_Description() {
        return holder.format("PermissionRemove_Description");
    }

    /**
     * Remove Failure causes.
     * 
     */
    public static Localizable _PermissionRemove_Description() {
        return new Localizable(holder, "PermissionRemove_Description");
    }

    /**
     * Connection OK!
     * 
     */
    public static String MongoDBKnowledgeBase_ConnectionOK() {
        return holder.format("MongoDBKnowledgeBase_ConnectionOK");
    }

    /**
     * Connection OK!
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_ConnectionOK() {
        return new Localizable(holder, "MongoDBKnowledgeBase_ConnectionOK");
    }

    /**
     * Failed to scan file
     * 
     */
    public static String FailedToScanFile_Error() {
        return holder.format("FailedToScanFile_Error");
    }

    /**
     * Failed to scan file
     * 
     */
    public static Localizable _FailedToScanFile_Error() {
        return new Localizable(holder, "FailedToScanFile_Error");
    }

    /**
     * String does not match pattern
     * 
     */
    public static String StringDoesNotMatchPattern() {
        return holder.format("StringDoesNotMatchPattern");
    }

    /**
     * String does not match pattern
     * 
     */
    public static Localizable _StringDoesNotMatchPattern() {
        return new Localizable(holder, "StringDoesNotMatchPattern");
    }

    /**
     * Do not Scan failed builds
     * 
     */
    public static String ScannerJobProperty_DisplayName() {
        return holder.format("ScannerJobProperty_DisplayName");
    }

    /**
     * Do not Scan failed builds
     * 
     */
    public static Localizable _ScannerJobProperty_DisplayName() {
        return new Localizable(holder, "ScannerJobProperty_DisplayName");
    }

    /**
     * Could not connect
     * 
     */
    public static String MongoDBKnowledgeBase_ConnectionError() {
        return holder.format("MongoDBKnowledgeBase_ConnectionError");
    }

    /**
     * Could not connect
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_ConnectionError() {
        return new Localizable(holder, "MongoDBKnowledgeBase_ConnectionError");
    }

    /**
     * Mongo DB
     * 
     */
    public static String MongoDBKnowledgeBase_DisplayName() {
        return holder.format("MongoDBKnowledgeBase_DisplayName");
    }

    /**
     * Mongo DB
     * 
     */
    public static Localizable _MongoDBKnowledgeBase_DisplayName() {
        return new Localizable(holder, "MongoDBKnowledgeBase_DisplayName");
    }

    /**
     * Multi-Line Build Log Indication
     * 
     */
    public static String MultilineBuildLogIndication_DisplayName() {
        return holder.format("MultilineBuildLogIndication_DisplayName");
    }

    /**
     * Multi-Line Build Log Indication
     * 
     */
    public static Localizable _MultilineBuildLogIndication_DisplayName() {
        return new Localizable(holder, "MultilineBuildLogIndication_DisplayName");
    }

    /**
     * Invalid pattern
     * 
     */
    public static String InvalidPattern_Error() {
        return holder.format("InvalidPattern_Error");
    }

    /**
     * Invalid pattern
     * 
     */
    public static Localizable _InvalidPattern_Error() {
        return new Localizable(holder, "InvalidPattern_Error");
    }

    /**
     * String matches pattern
     * 
     */
    public static String StringMatchesPattern() {
        return holder.format("StringMatchesPattern");
    }

    /**
     * String matches pattern
     * 
     */
    public static Localizable _StringMatchesPattern() {
        return new Localizable(holder, "StringMatchesPattern");
    }

    /**
     * Invalid URL
     * 
     */
    public static String InvalidURL_Error() {
        return holder.format("InvalidURL_Error");
    }

    /**
     * Invalid URL
     * 
     */
    public static Localizable _InvalidURL_Error() {
        return new Localizable(holder, "InvalidURL_Error");
    }

    /**
     * Failure Scan Options
     * 
     */
    public static String FailureScan_DisplayName() {
        return holder.format("FailureScan_DisplayName");
    }

    /**
     * Failure Scan Options
     * 
     */
    public static Localizable _FailureScan_DisplayName() {
        return new Localizable(holder, "FailureScan_DisplayName");
    }

    /**
     * Failure Cause Management
     * 
     */
    public static String CauseManagement_DisplayName() {
        return holder.format("CauseManagement_DisplayName");
    }

    /**
     * Failure Cause Management
     * 
     */
    public static Localizable _CauseManagement_DisplayName() {
        return new Localizable(holder, "CauseManagement_DisplayName");
    }

    /**
     * Build Failure Analyzer
     * 
     */
    public static String PermissionGroup_Title() {
        return holder.format("PermissionGroup_Title");
    }

    /**
     * Build Failure Analyzer
     * 
     */
    public static Localizable _PermissionGroup_Title() {
        return new Localizable(holder, "PermissionGroup_Title");
    }

    /**
     * Failure Causes
     * 
     */
    public static String CauseList_DisplayName() {
        return holder.format("CauseList_DisplayName");
    }

    /**
     * Failure Causes
     * 
     */
    public static Localizable _CauseList_DisplayName() {
        return new Localizable(holder, "CauseList_DisplayName");
    }

    /**
     * Jenkins Local
     * 
     */
    public static String LocalFileKnowledgeBase_DisplayName() {
        return holder.format("LocalFileKnowledgeBase_DisplayName");
    }

    /**
     * Jenkins Local
     * 
     */
    public static Localizable _LocalFileKnowledgeBase_DisplayName() {
        return new Localizable(holder, "LocalFileKnowledgeBase_DisplayName");
    }

    /**
     * {0} is missing the {1} or {2} permission
     * 
     */
    public static String SodAccessDeniedException(Object arg1, Object arg2, Object arg3) {
        return holder.format("SodAccessDeniedException", arg1, arg2, arg3);
    }

    /**
     * {0} is missing the {1} or {2} permission
     * 
     */
    public static Localizable _SodAccessDeniedException(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "SodAccessDeniedException", arg1, arg2, arg3);
    }

    /**
     * View Failure causes.
     * 
     */
    public static String PermissionView_Description() {
        return holder.format("PermissionView_Description");
    }

    /**
     * View Failure causes.
     * 
     */
    public static Localizable _PermissionView_Description() {
        return new Localizable(holder, "PermissionView_Description");
    }

}
